tinda
.  
.
.
#
Buggy Sub-Alpha stage.
.
.
.

# Usage:
.from tinda import *
.# doing that will enable you to use all functions they come.
.

.from tinda import linkDownloader
.linkDownloader('link')
.


Developed by Hank Singh (c)
© 2021 SINGHINDUSTRIES.

